/*=========================================================================

  Program:   Visualization Toolkit
  Module:    vtkTensorGlyph2.cxx

  Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
  All rights reserved.
  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.

     This software is distributed WITHOUT ANY WARRANTY; without even
     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
     PURPOSE.  See the above copyright notice for more information.

=========================================================================*/
#include "vtkTensorGlyph2.h"

#include "vtkInformation.h"
#include "vtkInformationVector.h"
#include "vtkObjectFactory.h"
#include "vtkPointData.h"
#include "vtkPolyData.h"

vtkStandardNewMacro(vtkTensorGlyph2);

vtkTensorGlyph2::vtkTensorGlyph2()
{
}

//----------------------------------------------------------------------------
vtkTensorGlyph2::~vtkTensorGlyph2()
{
}

//----------------------------------------------------------------------------
int vtkTensorGlyph2::RequestData(
  vtkInformation *request,
  vtkInformationVector **inputVector,
  vtkInformationVector *outputVector)
{
  this->Superclass::RequestData(request, inputVector, outputVector);

  // get info object
  vtkInformation *outInfo = outputVector->GetInformationObject(0);

  // get the output
  vtkPolyData *output = vtkPolyData::SafeDownCast(
    outInfo->Get(vtkDataObject::DATA_OBJECT()));

  vtkPointData *outPD;
  vtkDataArray *inScalars;

  outPD = output->GetPointData();

  if (outPD->GetScalars())
    {
    outPD->SetScalars(outPD->GetScalars());
    inScalars = this->GetInputArrayToProcess(1, inputVector);
    if ( this->ColorGlyphs && inScalars &&
         (this->ColorMode == COLOR_BY_SCALARS) )
      {
      outPD->GetScalars()->SetName(inScalars->GetName());
      }
    else if (this->ColorGlyphs &&
             (this->ColorMode == COLOR_BY_EIGENVALUES) )
      {
      outPD->GetScalars()->SetName("MaxEigenvalue");
      }
    else
      {
      outPD->GetScalars()->SetName("Scalars");
      }
    }

  if (outPD->GetNormals())
    {
    outPD->GetNormals()->SetName("Normals");
    }

  return 1;
}

//----------------------------------------------------------------------------
void vtkTensorGlyph2::PrintSelf(ostream& os, vtkIndent indent)
{
  this->Superclass::PrintSelf(os,indent);
}
